import * as d3 from 'd3';
import { globalSetting } from '../global';

export class WireRender {
    /**
     * 
     * @param {d3.Selection} selection 
     */
    constructor(selection) {
        this.selection = selection;
        
        /**
         * @type {BasicD3DataItem[]}
         */
        this.data = [];
    }

    /**
     * @description 将 elknode 关于 wire 的数据添加为 d3 数据项目
     * @param {ElkPoint[]} points 
     */
    addAsD3DataItems(points) {
        for (let i = 0; i < points.length - 1; ++ i) {
            this.data.push({
                x1: points[i].x,
                y1: points[i].y,
                x2: points[i + 1].x,
                y2: points[i + 1].y,
                strokeWidth: 2,
                color: 'var(--foreground)'
            });
        }
    }

    render() {
        const data = this.data;

        let lineSelections = this.selection.selectAll('line')
            .data(data)
            .enter()
            .append('line')
            .attr('x1', data => data.x1)
            .attr('y1', data => data.y1)
            .attr('x2', data => data.x2)
            .attr('y2', data => data.y2)
            .attr('stroke', data => data.color);
        
        if (globalSetting.renderAnimation) {
            lineSelections = lineSelections
                .transition()
                .duration(1000);
        }

        lineSelections.attr('stroke-width', data => data.strokeWidth);
        // line 就不注册拖拽事件了
    }
}